# Setup python target for shiboken so the right cmake file is imported.
%global py_suffix %(%{__python3} -c "import sysconfig; print(sysconfig.get_config_var('SOABI'))")

# Maintainers:  keep this list of plugins up to date
# List plugins in %%{_libdir}/freecad/lib, less '.so' and 'Gui.so', here
%global plugins Drawing Fem FreeCAD Image Import Inspection Mesh MeshPart Part Points QtUnit Raytracing ReverseEngineering Robot Sketcher Start Web _PartDesign Path Spreadsheet area DraftUtils libDriver libDriverDAT libDriverSTL libDriverUNV libE57Format libMEFISTO2 libSMDS libSMESH libSMESHDS libStdMeshers Measure TechDraw libarea-native Surface PathSimulator flatmesh libFreeCADApp libFreeCADBase PathApp

# Some plugins go in the Mod folder instead of lib. Deal with those here:
%global mod_plugins Mod/PartDesign

%define srcname FreeCAD

# Does not build with bundled version of OndselSolver
%bcond_without external_ondselsolver
%bcond_without external_pycxx
# We use the internal smesh version with fixes atm
%bcond_with    external_smesh
# We use bundled zipios for now as upstream still use 0.1
%bcond_with    external_zipios

%bcond_with    test

%ifarch aarch64 x86_64
%bcond_without web
%else
%bcond_with    web
%endif

# comment out when not a pre-release
#define prerel  rc2

Name:           freecad
Epoch:          1
Version:        1.0.0
Release:        1%{?dist}
Summary:        A general purpose 3D CAD modeler
Group:          Graphics/3D

License:        GPLv2+
URL:            https://www.freecadweb.org/
Source0:        https://github.com/FreeCAD/FreeCAD/archive/%{version}%{?prerel:%prerel}/%{srcname}-%{version}%{?prerel:%prerel}.tar.gz
Source102:      freecad.1

Patch2:         freecad-unbundled-pycxx.patch

# Utilities
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  dos2unix
BuildRequires:  doxygen
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
BuildRequires:  gettext
BuildRequires:  git-core
BuildRequires:  graphviz
BuildRequires:  swig

# Development Libraries
BuildRequires:  cmake(double-conversion)
BuildRequires:  cmake(GTest)
BuildRequires:  cmake(Microsoft.GSL)
BuildRequires:  cmake(pybind11)
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Help)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6SvgWidgets)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6UiTools)
%if %{with web}
BuildRequires:  cmake(Qt6WebEngineWidgets)
%endif
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(yaml-cpp)
BuildRequires:  boost-devel
BuildRequires:  freeglut-devel
BuildRequires:  freeimage-devel
BuildRequires:  glibc-devel
BuildRequires:  hdf5-devel
BuildRequires:  libicu-devel
BuildRequires:  libkdtree++-devel
BuildRequires:  libspnav-devel
BuildRequires:  med-devel
BuildRequires:  opencascade-devel
%if %{with external_smesh}
BuildRequires:  smesh-devel
%endif
# Does not build with current versions of OCCT
#BuildRequires:  netgen-mesher-devel
BuildRequires:  utf8cpp-devel
BuildRequires:  vtk-devel
%if %{with external_zipios}
BuildRequires:  zipios++-devel >= 2.0
%endif
BuildRequires:  pkgconfig(Coin)
%if %{with external_ondselsolver}
BuildRequires:  pkgconfig(OndselSolver)
%endif
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(ompi-cxx)
BuildRequires:  pkgconfig(python)
BuildRequires:  pkgconfig(xerces-c)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  python3dist(matplotlib)
BuildRequires:  python3-pivy
%if %{with external_pycxx}
BuildRequires:  python3-pycxx-devel
%endif
BuildRequires:  python3-pyside6-devel
BuildRequires:  python3-shiboken6-devel

# Packages separated because they are noarch, but not optional so require them
# here.
Requires:       %{name}-data = %{epoch}:%{version}-%{release}

%if %{with external_ondselsolver}
Requires:       libondselsolver
%endif
Requires:       openscad
Requires:       python3dist(matplotlib)
Requires:       python3dist(pycollada)
Requires:       python3dist(pyside6)
Requires:       python3dist(shiboken6)
Requires:       python3-pivy
Requires:       python3-six

Provides:       bundled(smesh)

%description
FreeCAD is a general purpose Open Source 3D CAD/MCAD/CAx/CAE/PLM modeler, aimed
directly at mechanical engineering and product design but also fits a wider
range of uses in engineering, such as architecture or other engineering
specialties. It is a feature-based parametric modeler with a modular software
architecture which makes it easy to provide additional functionality without
modifying the core system.


%package data
Summary:        Data files for FreeCAD
Group:          Graphics/3D
BuildArch:      noarch
Requires:       %{name} >= %{version}-%{release}
Requires:       qt6-assistant

%description data
Data files for FreeCAD.


%prep
%autosetup -p1 -n %{srcname}-%{version}%{?prerel:%prerel}

# Use system gtest - https://github.com/FreeCAD/FreeCAD/issues/10126
sed -i -e 's/add_subdirectory(lib)/find_package(GTest)/' \
       -e 's/ gtest_main/ GTest::gtest_main/' \
       -e 's/ gmock_main/ GTest::gmock_main/' \
       tests/CMakeLists.txt \
       tests/src/Mod/*/CMakeLists.txt

# Fix env-script-interpreter
sed -i '1 s@#!.*@#!%{__python3}@' \
       src/Mod/AddonManager/AddonManager.py \
       src/Mod/Mesh/App/MeshTestsApp.py \
       src/Mod/Part/parttests/ColorPerFaceTest.py \
       src/Mod/Part/parttests/TopoShapeListTest.py \
       src/Mod/Robot/KukaExporter.py \
       src/Mod/Robot/MovieTool.py \
       src/Mod/Spreadsheet/importXLSX.py \
       src/Mod/TechDraw/TDTest/D*Test.py \
       src/Mod/Test/testmakeWireString.py \
       src/Mod/Test/unittestgui.py

# Fix "wrong-script-end-of-line-encoding" rpmlint warning
sed -i 's/\r$//' src/Mod/Mesh/App/MeshTestsApp.py
sed -i 's/\r$//' src/Mod/Part/MakeBottle.py
sed -i 's/\r$//' src/Mod/PartDesign/Scripts/FilletArc.py
sed -i 's/\r$//' src/Mod/PartDesign/Scripts/Parallelepiped.py
sed -i 's/\r$//' src/Mod/PartDesign/Scripts/Spring.py
sed -i 's/\r$//' src/Mod/Robot/MovieTool.py
sed -i 's/\r$//' src/Mod/Robot/KukaExporter.py
sed -i 's/\r$//' src/Mod/Test/unittestgui.py

# Make sure system version is used
%if %{with external_ondselsolver}
rm src/3rdParty/OndselSolver -fr
%endif
%if %{with external_pycxx}
rm src/CXX -fr
%endif
%if %{with external_zipios}
rm src/zipios++ -fr
%endif

# Remove bundled gtest
rm tests/lib -fr


%build
%cmake -DENABLE_DEVELOPER_TESTS:BOOL=%{?with_tests:ON}%{!?with_tests:OFF} \
       -DCMAKE_SKIP_RPATH:BOOL=OFF \
       -DCMAKE_SKIP_INSTALL_RPATH:BOOL=OFF \
       -DCMAKE_INSTALL_RPATH_USE_LINK_PATH:BOOL=ON \
       -DCMAKE_INSTALL_PREFIX=%{_libdir}/%{name} \
       -DCMAKE_INSTALL_LIBDIR=%{_libdir}/%{name}/lib \
       -DCMAKE_INSTALL_DATADIR=%{_datadir}/%{name} \
       -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} \
       -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir} \
       -DRESOURCEDIR=%{_datadir}/%{name} \
       -DPYTHON_EXECUTABLE=%{__python3} \
       -DPYSIDE_INCLUDE_DIR=/usr/include/PySide6 \
       -DPYSIDE_LIBRARY=%{_libdir}/libpyside6.%{py_suffix}.so \
       -DSHIBOKEN_INCLUDE_DIR=%{_includedir}/shiboken6 \
       -DSHIBOKEN_LIBRARY=%{_libdir}/libshiboken6.%{py_suffix}.so \
       %if %{with external_pycxx}
       -DPYCXX_INCLUDE_DIR=$(pkg-config --variable=includedir PyCXX) \
       -DPYCXX_SOURCE_DIR=$(pkg-config --variable=srcdir PyCXX) \
       %endif
       -DBUILD_ENABLE_CXX_STD="C++17" \
       -DBUILD_WEB:BOOL=%{?with_web:ON}%{!?with_web:OFF} \
       -DCOIN3D_INCLUDE_DIRS=%{_includedir}/Coin4 \
       -DCOIN3D_DOC_PATH=%{_docdir}/Coin4/html \
       -DMEDFILE_INCLUDE_DIRS=%{_includedir}/med \
       -DOpenGL_GL_PREFERENCE=GLVND \
       -DOPENMPI_INCLUDE_DIRS=%{_includedir} \
       -DUSE_OCC=TRUE \
       -DOCC_INCLUDE_DIR=%{_includedir}/opencascade \
       -DFREECAD_QT_VERSION=6 \
       -DFREECAD_USE_PYBIND11:BOOL=ON \
       -DFREECAD_USE_EXTERNAL_FMT:BOOL=ON \
       -DFREECAD_USE_EXTERNAL_ONDSELSOLVER:BOOL=%{?with_external_ondselsolver:ON}%{!?with_external_ondselsolver:OFF} \
       -DFREECAD_USE_EXTERNAL_PIVY:BOOL=ON \
       %if %{with external_smesh}
       -DFREECAD_USE_EXTERNAL_SMESH:BOOL=%{?with_external_smesh:ON}%{!?with__external_smesh:OFF} \
       -DSMESH_INCLUDE_DIR=%{_includedir}/smesh \
       %endif
       -DFREECAD_USE_EXTERNAL_ZIPIOS:BOOL=%{?with_external_zipios:ON}%{!?with_external_zipios:OFF} \
       -Wno-dev

%cmake_build


%install
%cmake_install

# Fix "non-executable-script" rpmlint warning
# Run after install, as CMake "install(FILES...) sets rw- permissions
chmod 755 %{buildroot}%{_libdir}/%{name}/Mod/AddonManager/AddonManager.py \
          %{buildroot}%{_libdir}/%{name}/Mod/Robot/KukaExporter.py \
          %{buildroot}%{_libdir}/%{name}/Mod/Robot/MovieTool.py \
          %{buildroot}%{_libdir}/%{name}/Mod/Spreadsheet/importXLSX.py \
          %{buildroot}%{_libdir}/%{name}/Mod/TechDraw/TDTest/D*Test.py \
          %{buildroot}%{_libdir}/%{name}/Mod/Test/testmakeWireString.py \
          %{buildroot}%{_libdir}/%{name}/Mod/Mesh/MeshTestsApp.py \
          %{buildroot}%{_libdir}/%{name}/Mod/Part/parttests/ColorPerFaceTest.py \
          %{buildroot}%{_libdir}/%{name}/Mod/Part/parttests/TopoShapeListTest.py \
          %{buildroot}%{_libdir}/%{name}/Mod/Test/unittestgui.py

# Launchers in /usr/bin
mkdir -p %{buildroot}%{_bindir}
cat > %{buildroot}%{_bindir}/FreeCAD << EOF
#!/bin/bash
LD_LIBRARY_PATH=%{_libdir}/freecad/lib %{_libdir}/freecad/bin/FreeCAD "\$@"
EOF

cat > %{buildroot}%{_bindir}/FreeCADCmd << EOF
#!/bin/bash
LD_LIBRARY_PATH=%{_libdir}/freecad/lib %{_libdir}/freecad/bin/FreeCADCmd "\$@"
EOF

chmod a+rx %{buildroot}%{_bindir}/FreeCAD
chmod a+rx %{buildroot}%{_bindir}/FreeCADCmd

# Move mis-installed files to the right location
# Need to figure out if FreeCAD can install correctly at some point.
mkdir -p %{buildroot}%{_datadir}
mv %{buildroot}%{_libdir}/%{name}/share/* \
   %{buildroot}%{_datadir}

# Install man page
install -pD -m 0644 %{SOURCE102} \
    %{buildroot}%{_mandir}/man1/%{name}.1

# Symlink manpage to other binary names
pushd %{buildroot}%{_mandir}/man1
ln -sf %{name}.1.gz FreeCAD.1.xz
ln -sf %{name}.1.gz FreeCADCmd.1.xz
popd

# Remove header from external library that's erroneously installed
rm -f %{buildroot}%{_libdir}/%{name}/include/E57Format/E57Export.h

# Bytecompile Python modules
%py_byte_compile %{__python3} %{buildroot}%{_libdir}/%{name}


%check
desktop-file-validate \
    %{buildroot}%{_datadir}/applications/org.%{name}.%{srcname}.desktop
%{?fedora:appstream-util validate-relax --nonet \
    %{buildroot}%{_metainfodir}/*.appdata.xml}

%if %{with test}
export QT_QPA_PLATFORM=offscreen
%ctest --test-dir tests
%endif


%files
%license LICENSE
%doc README.md
%{_bindir}/*
%{_metainfodir}/org.%{name}.%{srcname}.metainfo.xml
%{_datadir}/applications/org.%{name}.%{srcname}.desktop
%{_datadir}/icons/hicolor/*/apps/org.%{name}.%{srcname}.png
%{_datadir}/icons/hicolor/scalable/apps/org.%{name}.%{srcname}.svg
%{_datadir}/icons/hicolor/scalable/mimetypes/application-x-extension-fcstd.svg
%{_datadir}/mime/packages/org.%{name}.%{srcname}.xml
%{_datadir}/pixmaps/%{name}.xpm
%{_datadir}/thumbnailers/%{srcname}.thumbnailer
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/bin/
%{_libdir}/%{name}/lib/
%{_libdir}/%{name}/Ext/
%{_libdir}/%{name}/Mod/
%{_mandir}/man1/*.1.*
%if 0%{?python3_version_nodots} > 39
%pycached %{python3_sitelib}/freecad/*.py
%else
%pycached %{python3_sitearch}/freecad/*.py
%endif

%files data
%{_datadir}/%{name}/
%{_docdir}/%{name}/{LICENSE.html,ThirdPartyLibraries.html}


%changelog
* Mon Jan 06 2025 Jean-Marc Liger <ligenix@iscp.fr> - 1.0.0-1
- Update to 1.0.0.
- Rebuild with QT6 from Mageia
- Add external pycxx from Mageia
- Add external tests from OpenSUSE

* Mon Feb 20 2023 Jonathan Wakely <jwakely@redhat.com> - 1:0.20.2-4
- Rebuilt for Boost 1.81

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.20.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sun Jan 15 2023 Orion Poplawski <orion@nwra.com> - 1:0.20.2-2
- Rebuild for vtk 9.2.5

* Fri Jan 13 2023 Richard Shaw <hobbes1069@gmail.com> - 1:0.20.2-1
- Update to 0.20.2.

* Tue Aug 30 2022 Richard Shaw <hobbes1069@gmail.com> - 1:0.20.1-1.1
- Rebuild for retagged upstream source, fixes rhbz#2121671.
- Readd Python 3.11 patches that did not make it into the current release.

* Tue Aug 09 2022 Richard Shaw <hobbes1069@gmail.com> - 1:0.20.1-1
- Update to 0.20.1.

* Thu Jul 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.20-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Jun 29 2022 Richard Shaw <hobbes1069@gmail.com> - 1:0.20-1
- Update to 0.20.

* Fri Jun 24 2022 Jonathan Wakely <jwakely@redhat.com> -1:0.19.4-4
- Remove obsolete boost-python3-devel build dependency (#2100748)

* Wed May 11 2022 Richard Shaw <hobbes1069@gmail.com> - 1:0.19.4-3
- Add patch to provide std::unique_ptr, fixes #2084307.

* Wed May 04 2022 Thomas Rodgers <trodgers@redhat.com> - 1:0.19.4-2
- Rebuilt for Boost 1.78

* Tue Mar 01 2022 Richard Shaw <hobbes1069@gmail.com> - 1:0.19.4-1
- Update to 0.19.4.

* Sat Jan 29 2022 Richard Shaw <hobbes1069@gmail.com> - 1:0.19.3-1
- Update to 0.19.3.

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.19.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Nov 25 2021 Orion Poplawski <orion@nwra.com> - 1:0.19.2-6
- Rebuild for vtk 9.1.0

* Thu Aug 19 2021 Richard Shaw <hobbes1069@gmail.com> - 1:0.19.2-5
- Add patch from upstream for better vtk9 compatibility.

* Fri Aug 06 2021 Jonathan Wakely <jwakely@redhat.com> - 1:0.19.2-4
- Rebuilt for Boost 1.76

* Wed Jul 21 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.19.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 1:0.19.2-2
- Rebuilt for Python 3.10

* Wed May 05 2021 Richard Shaw <hobbes1069@gmail.com> - 1:0.19.2-1
- Update to 0.19.2.

* Tue Mar 30 2021 Jonathan Wakely <jwakely@redhat.com> - 1:0.19-0.8.20210130git4db83a41ca
- Rebuilt for removed libstdc++ symbol (#1937698)

* Sun Feb 21 2021 Richard Shaw <hobbes1069@gmail.com> - 1:0.19-0.8.20210221git110860fa47
- Update to 110860fa4700dabf263918f80afcc75982b7dc37.

* Sun Jan 31 2021 Orion Poplawski <orion@nwra.com> - 1:0.19-0.7.20210130git4db83a41ca
- Rebuild for VTK 9

* Sat Jan 30 2021 Richard Shaw <hobbes1069@gmail.com> - 1:0.19-0.6.20210130git4db83a41ca
- Update to 0.19pre, git 4db83a41ca5800a0238a3030c81e33950c3070a3.

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.19-0.5.20201125gita50ae33557
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Jan 22 2021 Jonathan Wakely <jwakely@redhat.com> - 1:0.19-0.4.20201125gita50ae33557
- Rebuilt for Boost 1.75

* Wed Nov 25 2020 Richard Shaw <hobbes1069@gmail.com> - 1:0.19-0.3.20201125gita50ae33557
- Rebuild with OCC 7.5.0.

* Wed Nov 25 2020 Richard Shaw <hobbes1069@gmail.com> - 1:0.19-0.2.20201125gita50ae33557
- Update to latest git checkout, properly fixes ambiguous reference in
  Part/Sketcher.

* Wed Nov 25 2020 Richard Shaw <hobbes1069@gmail.com> - 1:0.19-0.1.20201124git6bd39e8a90
- Update to 0.19 pre-release.

* Mon Nov 23 2020 Richard Shaw <hobbes1069@gmail.com> - 1:0.18.4-13
- Rebuild for OpenCascade 7.5.0.

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.18.4-12
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jul 27 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.18.4-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Jun 20 2020 Miro Hrončok <mhroncok@redhat.com> - 1:0.18.4-10
- Bytecompile Python modules

* Wed Jun 03 2020 Scott Talbert <swt@techie.net> - 1:0.18.4-9
- Fix build with unbundled pycxx

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 1:0.18.4-8
- Rebuilt for Python 3.9

* Tue May 05 2020 Richard Shaw <hobbes1069@gmail.com> - 1:0.18.4-7
- Rebuild for Pyside2 5.14.

* Tue Jan 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.18.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jan 16 2020 Richard Shaw <hobbes1069@gmail.com> - 1:0.18.4-5
- Move < f32 back to Coin3.

* Thu Jan 09 2020 Richard Shaw <hobbes1069@gmail.com> - 1:0.18.4-2
- Rebuild for Qt/PySide 5.13.2.

* Tue Nov 05 2019 Richard Shaw <hobbes1069@gmail.com> - 1:0.18.4-1
- Update to 0.18.4.

* Mon Nov 04 2019 Richard Shaw <hobbes1069@gmail.com> - 1:0.18.3-7
- Fix python3-pyside2 requires and other specfile cleanup.

* Mon Oct 28 2019 Richard Shaw <hobbes1069@gmail.com> - 1:0.18.3-6
- Rebuild for downgraded PySide2 so the version matches with Qt5.

* Thu Oct 10 2019 Richard Shaw <hobbes1069@gmail.com> - 1:0.18.3-5.1
- Rebuild for Coin4 and python-pyside2 on rawhide (f32).
- Rebuild for python-pyside2 only for others.

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 1:0.18.3-4
- Rebuilt for Python 3.8

* Sat Jul 27 2019 Ivan Mironov <mironov.ivan@gmail.com> - 1:0.18.3-3
- Build C++ code with usual CXXFLAGS (including -O2)

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.18.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Thu Jul 18 2019 Richard Shaw <hobbes1069@gmail.com> - 1:0.18.3-1
- Update to 0.18.3.

* Mon May 20 2019 Richard Shaw <hobbes1069@gmail.com> - 1:0.18.2-3
- Bump release so NVER is higher on f31 than f30 & f29.

* Sun May 19 2019 Richard Shaw <hobbes1069@gmail.com> - 1:0.18.2-2
- Remove more python2 dependencies and fix shiboken building with python2.

* Sun May 12 2019 Richard Shaw <hobbes1069@gmail.com> - 1:0.18.2-1
- Update to 0.18.2.
- Hopefully fix python3 issues.

* Sun Mar 24 2019 Richard Shaw <hobbes1069@gmail.com> - 1:0.18-2
- Rebuild to require python3 pivy and collada.

* Wed Mar 13 2019 Richard Shaw <hobbes1069@gmail.com> - 1:0.18-1
- Update to 0.18.

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.17-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.17-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Apr 10 2018 Richard Shaw <hobbes1069@gmail.com> - 1:0.17-1
- Update to 0.17 release.

* Sat Mar 31 2018 Richard Shaw <hobbes1069@gmail.com> - 1:0.17-0.1
- Update to 0.17 prerelease.

* Wed Mar 07 2018 Adam Williamson <awilliam@redhat.com> - 1:0.16-12
- Rebuild to fix GCC 8 mis-compilation
  See https://da.gd/YJVwk ("GCC 8 ABI change on x86_64")

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.16-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 23 2017 Richard Shaw <hobbes1069@gmail.com> - 1:0.16-10
- Add qt-assistant so that help works properly.

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.16-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.16-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Jul 21 2017 Kalev Lember <klember@redhat.com> - 1:0.16-7
- Rebuilt for Boost 1.64

* Thu May 11 2017 Richard Shaw <hobbes1069@gmail.com> - 1:0.16-6
- Rebuild for OCE 0.18.1.

* Tue Feb 07 2017 Kalev Lember <klember@redhat.com> - 1:0.16-5
- Rebuilt for Boost 1.63

* Wed Dec 28 2016 Rich Mattes <richmattes@gmail.com> - 1:0.16-4
- Rebuild for eigen3-3.3.1

* Mon Sep 26 2016 Dominik Mierzejewski <rpm@greysector.net> - 1:0.16-3
- rebuilt for matplotlib-2.0.0

* Tue May 17 2016 Jonathan Wakely <jwakely@redhat.com> - 1:0.16-2
- Rebuilt for linker errors in boost (#1331983)

* Wed Apr 13 2016 Richard Shaw <hobbes1069@gmail.com> - 1:0.16-1
- Update to latest upstream release.

* Wed Apr  6 2016 Richard Shaw <hobbes1069@gmail.com> - 1:0.16-0.1
- Update to 0.16 prerelease.

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.15-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jan 28 2016 Jonathan Wakely <jwakely@redhat.com> 0.15-11
- Patched and rebuilt for Boost 1.60

* Mon Jan  4 2016 Richard Shaw <hobbes1069@gmail.com> - 1:0.15-10
- Fix appdata license, fixes BZ#1294623.

* Thu Aug 27 2015 Jonathan Wakely <jwakely@redhat.com> - 1:0.15-9
- Rebuilt for Boost 1.59

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.15-8
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 1:0.15-7
- rebuild for Boost 1.58

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.15-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu May 28 2015 Richard Shaw <hobbes1069@gmail.com> - 1:0.15-5
- Fix version reporting in the About dialog (BZ#1192841).

* Tue May 19 2015 Richard Shaw <hobbes1069@gmail.com> - 1:0.15-4
- Bump Epoch to downgrade to 0.14 for Fedora 21 and below due to Coin2/Coin3
  library mismatch between Freecad & python-pivy (BZ#1221713).

* Fri Apr 10 2015 Richard Shaw <hobbes1069@gmail.com> - 0.15-1
- Update to latest upstream release.

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> - 0.14-6
- Rebuild for boost 1.57.0

* Tue Jan  6 2015 Richard Shaw <hobbes1069@gmail.com> - 0.14-5
- Fix bug introduced by PythonSnap patch, fixes BZ#1178672.

* Thu Sep 18 2014 Richard Shaw <hobbes1069@gmail.com> - 0.14-4
- Patch PythonSnap, fixes BZ#1143814.

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.14-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Aug  4 2014 Richard Shaw <hobbes1069@gmail.com> - 0.14-2
- Add python-pyside as requirement as it is not currently being pulled in as a
  automatic dependency by rpmbuild.

* Wed Jul 16 2014 Richard Shaw <hobbes1069@gmail.com> - 0.14-1
- Update to latest upstream release.

* Mon Jun 23 2014 John Morris <john@zultron.com> - 0.13-10
- Add Requires: qt-assistant for bz #1112045

* Thu Jun 19 2014 Richard Shaw <hobbes1069@gmail.com> - 0.13-9
- Fix obsoletes of old documentation subpackage.
- Add conditional so EPEL 6 ppc64 does not require python-pivy which does not
  build on that platform.

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu May 29 2014 Richard Shaw <hobbes1069@gmail.com> - 0.13-7
- Update OCE patch with bad conditional which caused undefined symbols.

* Fri May 23 2014 Richard Shaw <hobbes1069@gmail.com> - 0.13-6
- Fix duplicate documentation.
- Correct license tag to GPLv2+.

* Mon May 19 2014 Richard Shaw <hobbes1069@gmail.com> - 0.13-5
- Move noarch data into it's own subpackage.
- Fix cmake conditionals to work for epel7.

* Thu Oct 10 2013 Richard Shaw <hobbes1069@gmail.com> - 0.13-4
- Rebuild for OCE 0.13.

* Mon Jul 15 2013 Richard Shaw <hobbes1069@gmail.com> - 0.13-3
- Rebuild for updated OCE.

* Mon Apr 29 2013 Nicolas Chauvet <kwizart@gmail.com> - 0.13-2
- https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Feb 18 2013 Richard Shaw <hobbes1069@gmail.com> - 0.13-1
- Update to latest upstream release.

* Sat Oct 20 2012 John Morris <john@zultron.com> - 0.12-9
- Use cmake28 package on el6
- Remove COIN3D_DOC_PATH cmake def (one less warning during build)
- Add PyQt as requirement.
- Add libicu-devel as build requirement.

* Wed Sep 26 2012 Richard Shaw <hobbes1069@gmail.com> - 0.12-8
- Rebuild for boost 1.50.

* Thu Jul 05 2012 Richard Shaw <hobbes1069@gmail.com> - 0.12-7
- Remove BuildRequires: tbb-devel and gts-devel
- Add missing license files to %%doc.
- Add missing requirement for hicolor-icon-theme.
- Fix excessive linking issue.
- Other minor spec updates.

* Mon Jun 25 2012  <john@zultron.com> - 0.12-6
- Filter out automatically generated Provides/Requires of private libraries
- freecad.desktop not passing 'desktop-file-validate'; fixed
- Remove BuildRequires: tbb-devel and gts-devel
- Update license tag to GPLv3+ only.
- Add missing license files to %%doc.
- Add missing build requirement for hicolor-icon-theme.
- Fix excessive linking issue.
- Other minor spec updates.

* Mon Jun 25 2012  <john@zultron.com> - 0.12-5
- New patch to unbundle PyCXX
- Add conditional build options for OpenCASCADE, bundled Zipios++,
  bundled PyCXX, bundled smesh

* Tue Jun 19 2012 Richard Shaw <hobbes1069@gmail.com> - 0.12-4
- Add linker flag to stop excessive linking.

* Thu May 31 2012 Richard Shaw <hobbes1069@gmail.com> - 0.12-3
- Add patch for GCC 4.7 on Fedora 17.

* Thu Nov 10 2011 Richard Shaw <hobbes1069@gmail.com> - 0.12-2
- Initial release.
